==> plugin.video.streamz-1.1.3%2Bmatrix.1.zip: plugin.video.streamz/CHANGELOG.md <==
# Changelog

## [v1.1.3](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.3) (2023-11-04)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.2...v1.1.3)

**Fixed bugs:**

- Upgrade API to 14 [\#58](https://github.com/add-ons/plugin.video.streamz/pull/58) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.2](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.2) (2023-01-13)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.1...v1.1.2)

**Implemented enhancements:**

- Remove manifest proxy [\#52](https://github.com/add-ons/plugin.video.streamz/pull/52) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Update to version 13 API \(part 2\) [\#54](https://github.com/add-ons/plugin.video.streamz/pull/54) ([michaelarnauts](https://github.com/michaelarnauts))
- Add support for media protected with drmtoday [\#53](https://github.com/add-ons/plugin.video.streamz/pull/53) ([michaelarnauts](https://github.com/michaelarnauts))
- Update to version 13 API [\#51](https://github.com/add-ons/plugin.video.streamz/pull/51) ([mediaminister](https://github.com/mediaminister))
- Support Python 3.10 [\#49](https://github.com/add-ons/plugin.video.streamz/pull/49) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.1](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.1) (2022-06-06)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.0...v1.1.1)

**Implemented enhancements:**

- Allow to clear the cache and don't use bad cached values [\#48](https://github.com/add-ons/plugin.video.streamz/pull/48) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Changes for API 12 [\#47](https://github.com/add-ons/plugin.video.streamz/pull/47) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.0](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.0) (2021-12-19)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.6...v1.1.0)

**Implemented enhancements:**

- Update artwork [\#41](https://github.com/add-ons/plugin.video.streamz/pull/41) ([michaelarnauts](https://github.com/michaelarnauts))
- Upgrade to API v10 [\#40](https://github.com/add-ons/plugin.video.streamz/pull/40) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Use new authentication flow [\#43](https://github.com/add-ons/plugin.video.streamz/pull/43) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.6](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.6) (2021-04-01)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.5...v1.0.6)

**Merged pull requests:**

- Implement new authentication method [\#38](https://github.com/add-ons/plugin.video.streamz/pull/38) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.5](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.5) (2021-02-04)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.4...v1.0.5)

**Implemented enhancements:**

- Indicate what movies or series are not available in your subscription [\#35](https://github.com/add-ons/plugin.video.streamz/pull/35) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Make use of git archive [\#34](https://github.com/add-ons/plugin.video.streamz/pull/34) ([dagwieers](https://github.com/dagwieers))

## [v1.0.4](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.4) (2021-01-13)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.3...v1.0.4)

**Implemented enhancements:**

- Add HTTP Proxy support [\#31](https://github.com/add-ons/plugin.video.streamz/pull/31) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Improve tests [\#32](https://github.com/add-ons/plugin.video.streamz/pull/32) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.3](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.3) (2021-01-01)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.2...v1.0.3)

**Implemented enhancements:**

- Add support for external subtitles [\#28](https://github.com/add-ons/plugin.video.streamz/pull/28) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Add proxy to modify the MPEG DASH Manifest [\#26](https://github.com/add-ons/plugin.video.streamz/pull/26) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.2](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.2) (2020-12-21)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.1...v1.0.2)

**Fixed bugs:**

- Don't show the password in the debug log [\#24](https://github.com/add-ons/plugin.video.streamz/pull/24) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Run CI on Windows [\#23](https://github.com/add-ons/plugin.video.streamz/pull/23) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.1](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.1) (2020-12-07)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.0...v1.0.1)

**Implemented enhancements:**

- Allow displaying all items in a recommendation category [\#20](https://github.com/add-ons/plugin.video.streamz/pull/20) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Run tests for Python 3.9 [\#21](https://github.com/add-ons/plugin.video.streamz/pull/21) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.0](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.0) (2020-11-03)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v0.0.1...v1.0.0)

**Implemented enhancements:**

- Allow to install and run Kodi Logfile Uploader from the settings [\#17](https://github.com/add-ons/plugin.video.streamz/pull/17) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve login flow [\#16](https://github.com/add-ons/plugin.video.streamz/pull/16) ([michaelarnauts](https://github.com/michaelarnauts))
- Various fixes [\#13](https://github.com/add-ons/plugin.video.streamz/pull/13) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve error handling and code cleanup [\#10](https://github.com/add-ons/plugin.video.streamz/pull/10) ([michaelarnauts](https://github.com/michaelarnauts))
- Integrate Movies and TV Series into the Kodi library [\#9](https://github.com/add-ons/plugin.video.streamz/pull/9) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Fix logging for Kodi Matrix [\#15](https://github.com/add-ons/plugin.video.streamz/pull/15) ([michaelarnauts](https://github.com/michaelarnauts))
- Fix for upcoming UpNext release. [\#12](https://github.com/add-ons/plugin.video.streamz/pull/12) ([michaelarnauts](https://github.com/michaelarnauts))

## [v0.0.1](https://github.com/add-ons/plugin.video.streamz/tree/v0.0.1) (2020-09-21)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/9931b4bbe8d675a77582f0f82128cd9552dd80da...v0.0.1)

**Implemented enhancements:**

- Add Telenet login provider [\#4](https://github.com/add-ons/plugin.video.streamz/pull/4) ([mediaminister](https://github.com/mediaminister))
- Fix Up Next support [\#2](https://github.com/add-ons/plugin.video.streamz/pull/2) ([mediaminister](https://github.com/mediaminister))

**Fixed bugs:**

- Fix Kids profile [\#5](https://github.com/add-ons/plugin.video.streamz/pull/5) ([mediaminister](https://github.com/mediaminister))

**Merged pull requests:**

- Prepare for v0.0.1 release [\#6](https://github.com/add-ons/plugin.video.streamz/pull/6) ([dagwieers](https://github.com/dagwieers))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> plugin.video.streamz-1.1.4%2Bmatrix.1.zip: plugin.video.streamz/CHANGELOG.md <==
# Changelog

## [v1.1.4](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.4) (2024-02-26)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.3...v1.1.4)

**Fixed bugs:**

- Bump API to 15 [\#60](https://github.com/add-ons/plugin.video.streamz/pull/60) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.3](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.3) (2023-11-04)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.2...v1.1.3)

**Fixed bugs:**

- Upgrade API to 14 [\#58](https://github.com/add-ons/plugin.video.streamz/pull/58) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.2](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.2) (2023-01-13)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.1...v1.1.2)

**Implemented enhancements:**

- Remove manifest proxy [\#52](https://github.com/add-ons/plugin.video.streamz/pull/52) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Update to version 13 API \(part 2\) [\#54](https://github.com/add-ons/plugin.video.streamz/pull/54) ([michaelarnauts](https://github.com/michaelarnauts))
- Add support for media protected with drmtoday [\#53](https://github.com/add-ons/plugin.video.streamz/pull/53) ([michaelarnauts](https://github.com/michaelarnauts))
- Update to version 13 API [\#51](https://github.com/add-ons/plugin.video.streamz/pull/51) ([mediaminister](https://github.com/mediaminister))
- Support Python 3.10 [\#49](https://github.com/add-ons/plugin.video.streamz/pull/49) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.1](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.1) (2022-06-06)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.1.0...v1.1.1)

**Implemented enhancements:**

- Allow to clear the cache and don't use bad cached values [\#48](https://github.com/add-ons/plugin.video.streamz/pull/48) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Changes for API 12 [\#47](https://github.com/add-ons/plugin.video.streamz/pull/47) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.1.0](https://github.com/add-ons/plugin.video.streamz/tree/v1.1.0) (2021-12-19)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.6...v1.1.0)

**Implemented enhancements:**

- Update artwork [\#41](https://github.com/add-ons/plugin.video.streamz/pull/41) ([michaelarnauts](https://github.com/michaelarnauts))
- Upgrade to API v10 [\#40](https://github.com/add-ons/plugin.video.streamz/pull/40) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Use new authentication flow [\#43](https://github.com/add-ons/plugin.video.streamz/pull/43) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.6](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.6) (2021-04-01)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.5...v1.0.6)

**Merged pull requests:**

- Implement new authentication method [\#38](https://github.com/add-ons/plugin.video.streamz/pull/38) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.5](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.5) (2021-02-04)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.4...v1.0.5)

**Implemented enhancements:**

- Indicate what movies or series are not available in your subscription [\#35](https://github.com/add-ons/plugin.video.streamz/pull/35) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Make use of git archive [\#34](https://github.com/add-ons/plugin.video.streamz/pull/34) ([dagwieers](https://github.com/dagwieers))

## [v1.0.4](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.4) (2021-01-13)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.3...v1.0.4)

**Implemented enhancements:**

- Add HTTP Proxy support [\#31](https://github.com/add-ons/plugin.video.streamz/pull/31) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Improve tests [\#32](https://github.com/add-ons/plugin.video.streamz/pull/32) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.3](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.3) (2021-01-01)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.2...v1.0.3)

**Implemented enhancements:**

- Add support for external subtitles [\#28](https://github.com/add-ons/plugin.video.streamz/pull/28) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Add proxy to modify the MPEG DASH Manifest [\#26](https://github.com/add-ons/plugin.video.streamz/pull/26) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.2](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.2) (2020-12-21)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.1...v1.0.2)

**Fixed bugs:**

- Don't show the password in the debug log [\#24](https://github.com/add-ons/plugin.video.streamz/pull/24) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Run CI on Windows [\#23](https://github.com/add-ons/plugin.video.streamz/pull/23) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.1](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.1) (2020-12-07)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v1.0.0...v1.0.1)

**Implemented enhancements:**

- Allow displaying all items in a recommendation category [\#20](https://github.com/add-ons/plugin.video.streamz/pull/20) ([michaelarnauts](https://github.com/michaelarnauts))

**Merged pull requests:**

- Run tests for Python 3.9 [\#21](https://github.com/add-ons/plugin.video.streamz/pull/21) ([michaelarnauts](https://github.com/michaelarnauts))

## [v1.0.0](https://github.com/add-ons/plugin.video.streamz/tree/v1.0.0) (2020-11-03)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/v0.0.1...v1.0.0)

**Implemented enhancements:**

- Allow to install and run Kodi Logfile Uploader from the settings [\#17](https://github.com/add-ons/plugin.video.streamz/pull/17) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve login flow [\#16](https://github.com/add-ons/plugin.video.streamz/pull/16) ([michaelarnauts](https://github.com/michaelarnauts))
- Various fixes [\#13](https://github.com/add-ons/plugin.video.streamz/pull/13) ([michaelarnauts](https://github.com/michaelarnauts))
- Improve error handling and code cleanup [\#10](https://github.com/add-ons/plugin.video.streamz/pull/10) ([michaelarnauts](https://github.com/michaelarnauts))
- Integrate Movies and TV Series into the Kodi library [\#9](https://github.com/add-ons/plugin.video.streamz/pull/9) ([michaelarnauts](https://github.com/michaelarnauts))

**Fixed bugs:**

- Fix logging for Kodi Matrix [\#15](https://github.com/add-ons/plugin.video.streamz/pull/15) ([michaelarnauts](https://github.com/michaelarnauts))
- Fix for upcoming UpNext release. [\#12](https://github.com/add-ons/plugin.video.streamz/pull/12) ([michaelarnauts](https://github.com/michaelarnauts))

## [v0.0.1](https://github.com/add-ons/plugin.video.streamz/tree/v0.0.1) (2020-09-21)

[Full Changelog](https://github.com/add-ons/plugin.video.streamz/compare/9931b4bbe8d675a77582f0f82128cd9552dd80da...v0.0.1)

**Implemented enhancements:**

- Add Telenet login provider [\#4](https://github.com/add-ons/plugin.video.streamz/pull/4) ([mediaminister](https://github.com/mediaminister))
- Fix Up Next support [\#2](https://github.com/add-ons/plugin.video.streamz/pull/2) ([mediaminister](https://github.com/mediaminister))

**Fixed bugs:**

- Fix Kids profile [\#5](https://github.com/add-ons/plugin.video.streamz/pull/5) ([mediaminister](https://github.com/mediaminister))

**Merged pull requests:**

- Prepare for v0.0.1 release [\#6](https://github.com/add-ons/plugin.video.streamz/pull/6) ([dagwieers](https://github.com/dagwieers))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
